@@ -5,7 +5,9 @@ from braintree.configuration import Configuration
 from braintree.credit_card_gateway import CreditCardGateway
 from braintree.credit_card_verification_gateway import CreditCardVerificationGateway
 from braintree.customer_gateway import CustomerGateway
+from braintree.document_upload_gateway import DocumentUploadGateway
 from braintree.discount_gateway import DiscountGateway
+from braintree.dispute_gateway import DisputeGateway
 from braintree.merchant_account_gateway import MerchantAccountGateway
 from braintree.merchant_gateway import MerchantGateway
 from braintree.oauth_gateway import OAuthGateway
@@ -19,6 +21,7 @@ from braintree.testing_gateway import TestingGateway
 from braintree.transaction_gateway import TransactionGateway
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
 from braintree.us_bank_account_gateway import UsBankAccountGateway
+from braintree.ideal_payment_gateway import IdealPaymentGateway
 from braintree.webhook_notification_gateway import WebhookNotificationGateway
 from braintree.webhook_testing_gateway import WebhookTestingGateway
 import braintree.configuration
@@ -39,7 +42,9 @@ class BraintreeGateway(object):
         self.client_token = ClientTokenGateway(self)
         self.credit_card = CreditCardGateway(self)
         self.customer = CustomerGateway(self)
+        self.document_upload = DocumentUploadGateway(self)
         self.discount = DiscountGateway(self)
+        self.dispute = DisputeGateway(self)
         self.merchant_account = MerchantAccountGateway(self)
         self.merchant = MerchantGateway(self)
         self.oauth = OAuthGateway(self)
@@ -56,3 +61,4 @@ class BraintreeGateway(object):
         self.paypal_account = PayPalAccountGateway(self)
         self.testing = TestingGateway(self)
         self.us_bank_account = UsBankAccountGateway(self)
+        self.ideal_payment = IdealPaymentGateway(self)
